<copyright> TOM Glue project History class.
    Written by Pieter J. Schoenmakers <tiggr@gerbil.org>.

    Copyright (C) 1999 Pieter J. Schoenmakers.

    Documentation comments from the GNU History TeXinfo documentation,
    with added comments.

    <id>$Id: History.t,v 1.1 1999/06/18 10:51:37 tiggr Exp $</id>
    </copyright>

<c>
#include <stdio.h>
#include <tom/util.h>
#include <readline/history.h>

DECL_USEL (tom, _pi__byteStringContents);
</c>

<doc> The {History} class is the link from TOM to the functionality of the
    {history} library.  </doc>
implementation class
History

<doc><h3>Initializing History and State Management</h3></doc>

<doc> Begin a session in which the history functions might be used.  This
    initializes the interactive variables.  </doc>
void
  using_history
{
  <c>
    using_history ();
  </c>
}

<doc> Return a structure (a {HISTORY_STATE *}) describing the current state
    of the input history.  </doc>
pointer (result)
  get_history_state
{
  <c>
    result = history_get_history_state ();
  </c>
}

<doc> Set the state of the history list according to STATE (a {HISTORY_STATE
    *}).  </doc>
void
  set_history_state pointer state
{
  <c>
    history_set_history_state (state);
  </c>
}

<doc><h3>History List Management</h3></doc>

<doc> Place {string} at the end of the history list.  The associated data
    field (if any) is set to {NULL}.  </doc>
void
  add_history String string
{
  <c>
    {
      tom_int len;
      char *s;

      C_STRING_WITH_TOM_STRING (s, len, string);
      add_history (s);
    }
  </c>
}

<doc> Like {pointer remove_history int} (see below), but free the C string
    from the entry that is returned.  </doc>
void
  remove_history int which
{
  pointer p = [self remove_history which];

  <c>
    {
      HIST_ENTRY *e = p;
      free (e->line);
    }
  </c>
}

<doc> Remove history entry at offset {which} from the history.  The removed
    element is returned (a {HIST_ENTRY *}) so you can free the line, data,
    and containing structure.  </doc>
pointer (result)
  remove_history int which
{
  <c>
    result = remove_history (which);
  </c>
}

<doc> Make the history entry at offset {which} have {line} and {data}.  This
    returns the old entry so you can dispose of the data.  In the case of an
    invalid {which}, a {NULL} pointer is returned.  </doc>
pointer (result)
  replace_history_entry (int, pointer, pointer) (which, line, data)
{
  <c>
    result = replace_history_entry (which, line, data);
  </c>
}

<doc> Clear the history list by deleting all the entries.  </doc>
void
  clear_history
{
  <c>
    clear_history ();
  </c>
}

<doc> Stifle the history list, remembering only the last {max} entries.
    </doc>
void
  stifle_history int max
{
  <c>
    stifle_history (max);
  </c>
}

<doc> Stop stifling the history.  This returns the previous amount the
    history was stifled.  The value is positive if the history was stifled,
    negative if it was not.  </doc>
int
  unstifle_history
{
  <c>
    unstifle_history ();
  </c>
}

<doc> Returns {TRUE} if the history is stifled, {FALSE} if it is not.  </doc>
boolean (result)
  history_is_stifled
{
  <c>
    result = !! history_is_stifled ();
  </c>
}

// TODO
// Fri Jun 18 12:40:25 1999, tiggr@gerbil.org

<doc><h3>Information About the History List</h3></doc>

<doc><h3>Moving Around the History List</h3></doc>

<doc><h3>Searching the History List</h3></doc>

<doc><h3>Managing the History File</h3></doc>

<doc><h3>History Expansion</h3></doc>

<doc><h3>History Variables</h3></doc>

end;

implementation instance History end;
